/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact;

import java.util.Map;
import java.util.Properties;

import org.ow2.petals.admin.api.artifact.exception.ConfigurationParamComputeException;

/**
 * This class represents a remote JBI Component.
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class Component extends Artifact implements ArtifactState {

    public enum ComponentType {
        BC, SE
    };

    private final ComponentType type;

    private final ConfigurationPropertiesCallback configurationPropertiesCallback;

    private Properties parameters;

    private State state;

    public Component(final String name, final ComponentType type,
            final ConfigurationPropertiesCallback configurationPropertiesCallback) {
        super(name, type.toString());
        this.type = type;
        this.parameters = new Properties();
        this.state = State.UNKNOWN;
        this.configurationPropertiesCallback = configurationPropertiesCallback;
    }

    public Component(final String name, final ComponentType type, final Properties parameters) {
        super(name, type.toString());
        this.type = type;
        this.parameters = parameters;
        this.state = State.UNKNOWN;
        this.configurationPropertiesCallback = null;
    }

    public Component(final String name, final ComponentType type) {
        this(name, type, new Properties());
    }

    /**
     * Configure and set configuration parameters from old ones
     * 
     * @param oldConfigParam
     *            The old configuration parameters
     * @throws ConfigurationParamComputeException
     */
    public final void configure(final Map<String, String> oldConfigParam) throws ConfigurationParamComputeException {
        if (this.configurationPropertiesCallback != null) {
            this.parameters = this.configurationPropertiesCallback.compute(oldConfigParam);
        }
    }

    /**
     * Get the component type
     * 
     * @return the component type
     */
    public final ComponentType getComponentType() {
        return this.type;
    }

    /**
     * Get the parameters
     * 
     * @return the parameters
     */
    public final Properties getParameters() {
        return this.parameters;
    }

    @Override
    public State getState() {
        return this.state;
    }

    @Override
    public void setState(State state) {
        this.state = state;
    }

}
