/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * This class represents a remote JBI service assembly.
 * 
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class ServiceAssembly extends Artifact implements ArtifactState {

    public static final String TYPE = "SA";

    /**
     * XPath expression to access service units names
     */
    public static final String XPATH_JBI_SU_NAMES = "/*[local-name()='jbi']/*[local-name()='service-assembly']/*[local-name()='service-unit']/*[local-name()='identification']/*[local-name()='name']";

    /**
     * XPath expression to access components dependencies
     */
    public static final String XPATH_JBI_SU_COMPONENTS = "/*[local-name()='jbi']/*[local-name()='service-assembly']/*[local-name()='service-unit']/*[local-name()='target']/*[local-name()='component-name']";

    private State state;

    private List<ServiceUnit> serviceUnits;

    public ServiceAssembly(final String name) {
        this(name, new ArrayList<ServiceUnit>());
    }

    public ServiceAssembly(final String name, final List<ServiceUnit> serviceUnits) {
        super(name, TYPE);
        this.state = State.UNKNOWN;
        this.serviceUnits = serviceUnits;
    }

    public List<ServiceUnit> getServiceUnits() {
        return Collections.unmodifiableList(this.serviceUnits);
    }

    /**
     * Update the service assembly state
     * 
     * @param the
     *            service assembly state
     */
    public void setState(final State state) {
        this.state = state;
    }

    /**
     * Get the service assembly state
     * 
     * @return the service assembly state
     */
    public State getState() {
        return state;
    }
    
    public void addServiceUnit(final ServiceUnit serviceUnit) {
        this.serviceUnits.add(serviceUnit);
    }

}
