/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact.exception;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactException;

/**
 * Base exception for invalid ZIP archive
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class InvalidZipArchiveException extends ArtifactException {

    private static final long serialVersionUID = 113846393393947729L;

    /**
     * The invalid ZIP archive.
     */
    private final URL invalidZipArchive;

    /**
     * Create an invalid ZIP archive exception.
     * 
     * @param message
     *            The invalidity cause
     * @param invalidZipArchive
     *            The invalid ZIP archive
     */
    public InvalidZipArchiveException(final String message, final URL invalidZipArchive) {
        super(message);
        this.invalidZipArchive = invalidZipArchive;
    }

    /**
     * @return The invalid ZIP archive
     */
    public URL getInvalidZipArchive() {
        return invalidZipArchive;
    }

}
