/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.conf;

import java.net.URL;

/**
 * The configuration of the Petals Administration API
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsAdminConfiguration {

    /**
     * The artifact URL rewriter, see {@link ArtifactUrlRewriter}.
     */
    private final ArtifactUrlRewriter artifactUrlRewriter;

    /**
     * Create a Petals Administration API configuration with a default {@link ArtifactUrlRewriter} than does not
     * transform the artifact URL.
     */
    public PetalsAdminConfiguration() {
        this.artifactUrlRewriter = new ArtifactUrlRewriter() {

            @Override
            public URL rewrite(final URL artifactUrl) {
                return artifactUrl;
            }
        };
    }

    /**
     * Create a Petals Administration API configuration with a given {@link ArtifactUrlRewriter}
     */
    public PetalsAdminConfiguration(final ArtifactUrlRewriter artifactUrlRewriter) {
        this.artifactUrlRewriter = artifactUrlRewriter;
    }

    /**
     * @return The artifact URL rewriter
     */
    public ArtifactUrlRewriter getArtifactUrlRewriter() {
        return this.artifactUrlRewriter;
    }

}
