/**
 * Copyright (c) 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.exception;

/**
 * Exception thrown when an artifact can not be found.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class ArtifactNotFoundException extends ArtifactAdministrationException {

    private static final long serialVersionUID = 4339577587430827255L;

    /**
     * The artifact type.
     */
    private final String type;
    
    /**
     * The artifact name.
     */
    private final String name;

    /**
     * The artifact version.
     */
    private final String version;

    /**
     * @param type
     *            artifact type (SL,BC,SE,SA). Can be <code>null</code>.
     * @param name
     *            Artifact identifier. Not <code>null</code>.
     * @param version
     *            Artifact version, for artifact supporting version. Can be <code>null</code>.
     */
    public ArtifactNotFoundException(final String type, final String name, final String version) {
        super(ArtifactNotFoundException.getMessage(type, name, version));
        this.type = type;
        this.name = name;
        this.version = version;
    }

    private static final String getMessage(final String type, final String name, final String version) {
        final StringBuilder message = new StringBuilder("Cannot find the artifact [");
        message.append("name [").append(name).append(']');
        if (type != null) {
            message.append(", type [").append(type).append(']');
        }
        if (version != null) {
            message.append(", version [").append(version).append(']');
        }
        message.append(']');

        return message.toString();
    }

    /**
     * @return The artifact type
     */
    public String getType() {
        return this.type;
    }

    /**
     * @return The artifact name
     */
    public String getName() {
        return this.name;
    }

    /**
     * @return The artifact version
     */
    public String getVersion() {
        return this.version;
    }
}
