/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipOutputStream;

import org.junit.Rule;
import org.junit.rules.TemporaryFolder;

public class AbstractArtifactTest {

    public final static String BC_JBI = "bc.jbi.xml";

    public final static String SE_JBI = "se.jbi.xml";

    public final static String SA_JBI = "sa.jbi.xml";

    public final static String SL_JBI = "sl.jbi.xml";

    public final static String DEPLOYABLE_SU_JBI = "su-deployable-directly.jbi.xml";

    public final static String STANDARD_SU_JBI = "su-standard.jbi.xml";

    @Rule()
    public TemporaryFolder tempFolder = new TemporaryFolder();

    /**
     * Create jbi zip with the specifed jbi descriptor
     * 
     * @param jbiFile
     * @return url of the jbi zip
     * @throws ZipException
     * @throws IOException
     * @throws URISyntaxException
     *             Should be thrown
     */
    protected URL createArtifactURL(final String jbiFile) throws ZipException, IOException,
            URISyntaxException {
        byte[] buf = new byte[1024];
        final URL jbiURL = Thread.currentThread().getContextClassLoader().getResource(jbiFile);
        // To be able to create 2 URL in the same test, we must used random folder storing zip file.
        final File zip = new File(tempFolder.newFolder(), "artifact-jbi.zip");
        final ZipOutputStream zos = new ZipOutputStream(new FileOutputStream(zip));
        try {
            // copy file content into zipfile
            final FileInputStream fis = new FileInputStream(new File(jbiURL.toURI()));
            try {
                zos.putNextEntry(new ZipEntry("META-INF/jbi.xml"));
                try {
                    int len = 0;
                    while ((len = fis.read(buf)) > 0) {
                        zos.write(buf, 0, len);
                    }
                } finally {
                    zos.closeEntry();
                }
            } finally {
                fis.close();
            }
        } finally {
            zos.close();
        }
        return zip.toURI().toURL();
    }

}
