/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.api.artifact.lifecycle;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.io.IOException;
import java.net.URL;
import java.util.Enumeration;

import org.junit.Test;
import org.ow2.petals.admin.api.PetalsAdministrationFactory;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.Component.ComponentType;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.api.exception.DuplicatedServiceException;
import org.ow2.petals.admin.api.exception.MissingServiceException;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class ArtifactLifecycleFactoryTest {

    @Test
    public void createArtifactLifecycleTest() throws DuplicatedServiceException,
            MissingServiceException {
        final ClassLoader oldClassloader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(new ClassLoader(oldClassloader) {

            @Override
            public Enumeration<URL> getResources(final String name) throws IOException {
                if (name.equals("META-INF/services/" + PetalsAdministrationFactory.class.getName())) {
                    return super.getResources("services/mock-impl/"
                            + PetalsAdministrationFactory.class.getName());
                } else {
                    return super.getResources(name);
                }
            }
        });

        try {
            Component bc = new Component("petals-bc-test", ComponentType.BC);
            Component se = new Component("petals-se-test", ComponentType.SE);
            ServiceAssembly sa = new ServiceAssembly("sa-test");
            SharedLibrary sl = new SharedLibrary("sl-test", "v-test");
            final ArtifactLifecycleFactory artifactLifecycleFactory = PetalsAdministrationFactory.getInstance()
                    .newPetalsAdministrationAPI().newArtifactLifecycleFactory();

            ArtifactLifecycle artifactLifecycle = artifactLifecycleFactory.createLifecycle(bc);
            assertNotNull(artifactLifecycle);
            assertTrue(artifactLifecycle instanceof ComponentLifecycle);

            artifactLifecycle = artifactLifecycleFactory.createLifecycle(se);
            assertNotNull(artifactLifecycle);
            assertTrue(artifactLifecycle instanceof ComponentLifecycle);

            artifactLifecycle = artifactLifecycleFactory.createLifecycle(sa);
            assertNotNull(artifactLifecycle);
            assertTrue(artifactLifecycle instanceof ServiceAssemblyLifecycle);

            artifactLifecycle = artifactLifecycleFactory.createLifecycle(sl);
            assertNotNull(artifactLifecycle);
            assertTrue(artifactLifecycle instanceof SharedLibraryLifecycle);
        } finally {
            Thread.currentThread().setContextClassLoader(oldClassloader);
        }
    }

    public class UnknownArtifact extends Artifact {

        protected UnknownArtifact(final String name) {
            super(name, "test-type");
        }

    }

    @Test
    public void createArtifactLifecycleWithUnknowArtifactTest() throws DuplicatedServiceException,
            MissingServiceException {
        final ClassLoader oldClassloader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(new ClassLoader(oldClassloader) {

            @Override
            public Enumeration<URL> getResources(final String name) throws IOException {
                if (name.equals("META-INF/services/" + PetalsAdministrationFactory.class.getName())) {
                    return super.getResources("services/mock-impl/"
                            + PetalsAdministrationFactory.class.getName());
                } else {
                    return super.getResources(name);
                }
            }
        });

        try {
            UncheckedException e = null;
            ArtifactLifecycle artifactLifecycle = null;
            Artifact[] artifacts = new Artifact[2];
            artifacts[0] = null;
            artifacts[1] = new UnknownArtifact("test-name");
            final ArtifactLifecycleFactory artifactLifecycleFactory = PetalsAdministrationFactory.getInstance()
                    .newPetalsAdministrationAPI().newArtifactLifecycleFactory();

            for (int i = 0; i < artifacts.length; i++) {
                try {
                    artifactLifecycle = artifactLifecycleFactory.createLifecycle(
                            artifacts[i]);
                } catch (UncheckedException ex) {
                    e = ex;
                }
                assertNull(artifactLifecycle);
                assertNotNull(e);
                assertEquals("Unknow artifact type", e.getMessage());
            }
        } finally {
            Thread.currentThread().setContextClassLoader(oldClassloader);
        }
    }
}
